==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/KwalifikacjaOsWymagaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.generic.GenericDPSObject;

@GeneratePojoBuilder
public class KwalifikacjaOsWymagaKey extends GenericDPSObject {
    /**
     * KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long kwalifikacjaId;

    /**
     * KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long slowoId;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getKwalifikacjaId() {
        return kwalifikacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-10 10:45:42
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     *
     * @param kwalifikacjaId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setKwalifikacjaId(Long kwalifikacjaId) {
        this.kwalifikacjaId = kwalifikacjaId;
    }

    /**
     * @return KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KwalifikacjaOsWymagaKey other = (KwalifikacjaOsWymagaKey) that;
        return (this.getKwalifikacjaId() == null ? other.getKwalifikacjaId() == null : this.getKwalifikacjaId().equals(other.getKwalifikacjaId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKwalifikacjaId() == null) ? 0 : getKwalifikacjaId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kwalifikacjaId=").append(kwalifikacjaId);
        sb.append(", slowoId=").append(slowoId);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/KwalifikacjaOsWymagaKey.java <==
package pl.topteam.dps.model.main_gen;

import net.karneim.pojobuilder.GeneratePojoBuilder;

import pl.topteam.dps.model.main_gen.GenericDPSObject;

@GeneratePojoBuilder
public class KwalifikacjaOsWymagaKey extends GenericDPSObject {
    /**
     * KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long kwalifikacjaId;

    /**
     * KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long slowoId;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getKwalifikacjaId() {
        return kwalifikacjaId;
    }

	/**
	 * @return
	 * @mbggenerated 2014-03-13 16:02:46
	 */
	@Override
	public Long getId() {
		return -1L;
	}

    /**
     * KWALIFIKACJA_OS_WYMAGA.KWALIFIKACJA_ID
     *
     * @param kwalifikacjaId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setKwalifikacjaId(Long kwalifikacjaId) {
        this.kwalifikacjaId = kwalifikacjaId;
    }

    /**
     * @return KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSlowoId() {
        return slowoId;
    }

    /**
     * KWALIFIKACJA_OS_WYMAGA.SLOWO_ID
     *
     * @param slowoId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSlowoId(Long slowoId) {
        this.slowoId = slowoId;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        KwalifikacjaOsWymagaKey other = (KwalifikacjaOsWymagaKey) that;
        return (this.getKwalifikacjaId() == null ? other.getKwalifikacjaId() == null : this.getKwalifikacjaId().equals(other.getKwalifikacjaId()))
            && (this.getSlowoId() == null ? other.getSlowoId() == null : this.getSlowoId().equals(other.getSlowoId()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getKwalifikacjaId() == null) ? 0 : getKwalifikacjaId().hashCode());
        result = prime * result + ((getSlowoId() == null) ? 0 : getSlowoId().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", kwalifikacjaId=").append(kwalifikacjaId);
        sb.append(", slowoId=").append(slowoId);
        sb.append("]");
        return sb.toString();
    }
}
